Mirror of the lttng-dev mailing list
 help / color / mirror / Atom feed
From: jbernard@debian.org (Jon Bernard)
Subject: [ltt-dev] [LTTV PATCH] Fix informations typo
Date: Thu, 17 Feb 2011 20:26:43 -0500	[thread overview]
Message-ID: <20110218012639.GA30054@starquasia> (raw)

---
 doc/user/user_guide/docbook/user_guide.docbook |    2 +-
 lttv/lttv/state.h                              |    2 +-
 lttv/modules/text/formattedDump.c              |    4 ++--
 3 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/doc/user/user_guide/docbook/user_guide.docbook b/doc/user/user_guide/docbook/user_guide.docbook
index f58a5b2..e65c69c 100644
--- a/doc/user/user_guide/docbook/user_guide.docbook
+++ b/doc/user/user_guide/docbook/user_guide.docbook
@@ -195,7 +195,7 @@ necessary. You will find them in
 core.xml.
 </para>
 <para>
-sysInfo is a script that get informations about the traced computer. It should
+sysInfo is a script that get information about the traced computer. It should
 be invoked like this :
 </para>
 <screen>
diff --git a/lttv/lttv/state.h b/lttv/lttv/state.h
index 0ae7e5c..f6793eb 100644
--- a/lttv/lttv/state.h
+++ b/lttv/lttv/state.h
@@ -43,7 +43,7 @@
    which events have been processed) and a pointer to the current process,
    in the process table, being run on that cpu.
 
-   For each process in the process table, various informations such as exec 
+   For each process in the process table, various information such as exec 
    file name, pid, ppid and creation time are stored. Each process state also
    contains an execution mode stack (e.g. irq within system call, called
    from user mode). */
diff --git a/lttv/modules/text/formattedDump.c b/lttv/modules/text/formattedDump.c
index fa2422e..c4054aa 100644
--- a/lttv/modules/text/formattedDump.c
+++ b/lttv/modules/text/formattedDump.c
@@ -142,7 +142,7 @@ static int write_event_content(void *hook_data, void *call_data)
 
 	/*
 	 * By default, metadata's channel won't be display: it goes directly
 	 * to the next event. You can have metadata's informations with -M
 	 * switch (a_meta option).
 	 */
 	if (!a_meta && ltt_tracefile_name(tfs->parent.tf) ==
@@ -341,7 +341,7 @@ static void init()
 
 	a_meta = FALSE;
 	lttv_option_add("metadata", 'M',
-			"add metadata informations",
+			"add metadata information",
 			"",
 			LTTV_OPT_NONE, &a_meta, NULL, NULL);
 
@@ -142,7 +142,7 @@ static int write_event_content(void *hook_data, void *call_data)
 	/*
 	 * By default, metadata's channel won't be display: it goes directly
-	 * to the next event. You can have metadata's informations with -M
+	 * to the next event. You can have metadata's information with -M
 	 * switch (a_meta option).
 	 */
-- 




             reply	other threads:[~2011-02-18  1:26 UTC|newest]

Thread overview: 2+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2011-02-18  1:26 Jon Bernard [this message]
2011-02-18  2:45 ` Mathieu Desnoyers

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20110218012639.GA30054@starquasia \
    --to=jbernard@debian.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox